@@ -1,12 +1,13 @@
 # pylint: disable=wildcard-import,invalid-name,wrong-import-position
 """ArviZ is a library for exploratory analysis of Bayesian models."""
-__version__ = "0.12.1"
+__version__ = "0.13.0"
 
 import logging
 import os
 
 from matplotlib.colors import LinearSegmentedColormap
-from matplotlib.pyplot import register_cmap, style
+from matplotlib.pyplot import style
+import matplotlib as mpl
 
 
 class Logger(logging.Logger):
@@ -314,12 +315,15 @@ _linear_grey_10_95_c0 = [
 
 def _mpl_cm(name, colorlist):
     cmap = LinearSegmentedColormap.from_list(name, colorlist, N=256)
-    register_cmap("cet_" + name, cmap=cmap)
+    mpl.colormaps.register(cmap, name="cet_" + name)
 
 
-_mpl_cm("gray", _linear_grey_10_95_c0)
-_mpl_cm("gray_r", list(reversed(_linear_grey_10_95_c0)))
+try:
+    import colorcet
+except ModuleNotFoundError:
+    _mpl_cm("gray", _linear_grey_10_95_c0)
+    _mpl_cm("gray_r", list(reversed(_linear_grey_10_95_c0)))
 
 
 # clean namespace
-del os, logging, register_cmap, LinearSegmentedColormap, Logger
+del os, logging, LinearSegmentedColormap, Logger, mpl
