@@ -64,9 +64,8 @@ def plot_ppc(
 
         if len([item for item in axes.ravel() if not None]) != length_plotters:
             raise ValueError(
-                "Found {} variables to plot but {} axes instances. They must be equal.".format(
-                    length_plotters, len(axes)
-                )
+                f"Found {length_plotters} variables to plot but {len(axes)} axes instances. "
+                "They must be equal."
             )
 
     if alpha is None:
