@@ -140,7 +140,7 @@ def plot_dist_comparison(
 
     datasets = get_coords(datasets, coords)
     len_plots = rcParams["plot.max_subplots"] // (len(groups) + 1)
-    len_plots = len_plots if len_plots else 1
+    len_plots = len_plots or 1
     dc_plotters = [
         list(xarray_var_iter(data, var_names=var, combined=True, skip_dims=combine_dims))[
             :len_plots
