@@ -183,10 +183,7 @@ def plot_lm(
     elif isinstance(x, DataArray):
         x_skip_dims = x.dims
     elif x is None:
-        if plot_dim is None:
-            x = y.coords[y.dims[0]]
-        else:
-            x = y.coords[plot_dim]
+        x = y.coords[y.dims[0]] if plot_dim is None else y.coords[plot_dim]
         x_skip_dims = x.dims
     else:
         x = xr.DataArray(x)
@@ -230,9 +227,7 @@ def plot_lm(
             or num_samples < 1
             or num_samples > total_pp_samples
         ):
-            raise TypeError(
-                "`num_samples` must be an integer between 1 and " + f"{total_pp_samples}."
-            )
+            raise TypeError(f"`num_samples` must be an integer between 1 and {total_pp_samples}.")
 
         pp_sample_ix = np.random.choice(total_pp_samples, size=num_samples, replace=False)
 
