@@ -243,9 +243,8 @@ def plot_ppc(
     if backend is None:
         backend = rcParams["plot.backend"]
     backend = backend.lower()
-    if backend == "bokeh":
-        if animated:
-            raise TypeError("Animation option is only supported with matplotlib backend.")
+    if backend == "bokeh" and animated:
+        raise TypeError("Animation option is only supported with matplotlib backend.")
 
     observed_data = data.observed_data
 
@@ -260,10 +259,11 @@ def plot_ppc(
     pp_var_names = [data_pairs.get(var, var) for var in var_names]
     pp_var_names = _var_names(pp_var_names, predictive_dataset, filter_vars)
 
-    if flatten_pp is None and flatten is None:
-        flatten_pp = list(predictive_dataset.dims.keys())
-    elif flatten_pp is None:
-        flatten_pp = flatten
+    if flatten_pp is None:
+        if flatten is None:
+            flatten_pp = list(predictive_dataset.dims.keys())
+        else:
+            flatten_pp = flatten
     if flatten is None:
         flatten = list(observed_data.dims.keys())
 
@@ -288,9 +288,7 @@ def plot_ppc(
         or num_pp_samples < 1
         or num_pp_samples > total_pp_samples
     ):
-        raise TypeError(
-            "`num_pp_samples` must be an integer between 1 and " + f"{total_pp_samples}."
-        )
+        raise TypeError(f"`num_pp_samples` must be an integer between 1 and {total_pp_samples}.")
 
     pp_sample_ix = np.random.choice(total_pp_samples, size=num_pp_samples, replace=False)
 
