@@ -198,13 +198,16 @@ def plot_trace(
 
     var_names = _var_names(var_names, coords_data, filter_vars)
 
-    if compact:
-        skip_dims = set(coords_data.dims) - {"chain", "draw"}
-    else:
-        skip_dims = set()
+    skip_dims = set(coords_data.dims) - {"chain", "draw"} if compact else set()
 
     plotters = list(
-        xarray_var_iter(coords_data, var_names=var_names, combined=True, skip_dims=skip_dims)
+        xarray_var_iter(
+            coords_data,
+            var_names=var_names,
+            combined=True,
+            skip_dims=skip_dims,
+            dim_order=["chain", "draw"],
+        )
     )
     max_plots = rcParams["plot.max_subplots"]
     max_plots = len(plotters) if max_plots is None else max(max_plots // 2, 1)
