@@ -230,7 +230,9 @@ class TestDataPyMC3:
         df_data = pd.DataFrame(columns=["date"]).set_index("date")
         dates = pd.date_range(start="2020-05-01", end="2020-05-20")
         for city, mu in {"Berlin": 15, "San Marino": 18, "Paris": 16}.items():
-            df_data[city] = np.random.normal(loc=mu, size=len(dates))
+            df_data[city] = np.random.normal(  # pylint: disable=unsupported-assignment-operation
+                loc=mu, size=len(dates)
+            )
         df_data.index = dates
         df_data.index.name = "date"
 
